@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2025, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -23,6 +23,12 @@
  */
 
 #include <string>
+#if !defined(_MSC_VER)
+#include <fstream>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <glib.h>
+#endif
 
 #include "base/ui_form.h"
 #include "base/string_utilities.h"
@@ -73,6 +79,19 @@ DEFAULT_LOG_DOMAIN(DOMAIN_WB_CONTEXT_UI)
 
 //--------------------------------------------------------------------------------------------------
 
+static void write_lock_file() {
+  std::string userdir = mforms::App::get()->get_user_data_folder();
+  std::string lockfile = userdir + "/ma_lock_fisrt.lck";
+  struct stat buffer;
+  if (stat(lockfile.c_str(), &buffer) != 0) { // file does not exist
+    std::ofstream ofs(lockfile);
+    ofs << "locked";
+    ofs.close();
+  }
+}
+
+//--------------------------------------------------------------------------------------------------
+
 std::shared_ptr<WBContextUI> WBContextUI::get() {
   static std::shared_ptr<WBContextUI> _singleton(new WBContextUI());
   return _singleton;
@@ -128,10 +147,12 @@ void WBContextUI::cleanUp() {
   delete _command_ui;
   _command_ui = nullptr;
 
-
   // home screen should be released by undock operation,
   // but it will be left in bad state, we have to clear this
   _home_screen = nullptr;
+
+  // write lock indicator for new sticker (migration assistant)
+  write_lock_file();
 }
 
 //--------------------------------------------------------------------------------------------------
@@ -342,6 +363,9 @@ void WBContextUI::add_backend_builtin_commands() {
 
   _command_ui->add_builtin_command(
       "web_mysql_forum", std::bind(&WBContextUI::show_web_page, this, "https://forums.mysql.com/list.php?152", true));
+ 
+  _command_ui->add_builtin_command(
+    "web_migration_asistant_learn_more", std::bind(&WBContextUI::show_web_page, this, "https://dev.mysql.com/doc/workbench/en/heatwave-migration-assistant.html", true));
 
   if (_wb->is_commercial()) {
     _command_ui->add_builtin_command("web_support",
